ImbalancedEnsembleVisualizer
=========================================================================

.. currentmodule:: imbalanced_ensemble.visualizer

.. autoclass:: ImbalancedEnsembleVisualizer

   

   
   .. rubric:: Methods

   .. autosummary::
   
      
      
        ~ImbalancedEnsembleVisualizer.confusion_matrix_heatmap
      
      
        ~ImbalancedEnsembleVisualizer.fit
      
      
        ~ImbalancedEnsembleVisualizer.performance_lineplot
      
   
   

.. include:: ../../../back_references/imbalanced_ensemble.visualizer.ImbalancedEnsembleVisualizer.examples

.. raw:: html

    <div style='clear:both'></div>